@@ -63,6 +63,62 @@ formatEstimateValue <- function(result,
   return(result)
 }
 
+# Copyright 2025 DARWIN EU®
+#
+# This file is part of visOmopResults
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+#' To indicate which was the minimum cell counts where estimates have been
+#' suppressed.
+#' @param result A `<summarised_result>` object.
+#'
+#' @export
+#'
+#' @examples
+#' result <- mockSummarisedResult()
+#' result |> formatMinCellCount()
+
+formatMinCellCount <- function(result) {
+  # checks
+  result <- omopgenerics::validateResultArgument(result)
+  set <-  omopgenerics::settings(result)
+  if(!"min_cell_count" %in% colnames(set)) {
+    cli::cli_abort("There is no `min_cell_count` column in settings indicating that results have been suppressed.")
+  }
+
+  # add min cell count
+  if (is.null(set)) {
+    result <- result |>
+      omopgenerics::addSettings(settingsColumn = "min_cell_count")
+  } else {
+    result <- result |>
+      dplyr::left_join(
+        set |>
+          dplyr::select("result_id", "min_cell_count"),
+        by = "result_id"
+      )
+  }
+  result |>
+    dplyr::mutate(min_cell_count = paste0("<", base::format(as.numeric(.data$min_cell_count), big.mark = ",", scientific = FALSE))) |>
+    dplyr::mutate(estimate_value = dplyr::if_else(
+      .data$estimate_value == "-",
+      .data$min_cell_count,
+      .data$estimate_value
+    )) |>
+    dplyr::select(!"min_cell_count")
+}
+
 formatEstimateValueInternal <- function(result, decimals, decimalMark, bigMark) {
   nms_name <- unique(result[["estimate_name"]])
   if (is.null(decimals)) { # default decimal formatting
@@ -97,3 +153,5 @@ formatEstimateValueInternal <- function(result, decimals, decimalMark, bigMark)
   }
   return(result)
 }
+
+
